pub struct ProjectMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on project resources.
It is not used directly, but through the CloudPrivateCatalog hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_cloudprivatecatalog1_beta1 as cloudprivatecatalog1_beta1;
use cloudprivatecatalog1_beta1::{CloudPrivateCatalog, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = CloudPrivateCatalog::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `catalogs_search(...)`, `products_search(...)` and `versions_search(...)`
// to build up your call.
let rb = hub.projects();Implementations
Sourceimpl<'a, C> ProjectMethods<'a, C>
impl<'a, C> ProjectMethods<'a, C>
Sourcepub fn catalogs_search(&self, resource: &str) -> ProjectCatalogSearchCall<'a, C>
pub fn catalogs_search(&self, resource: &str) -> ProjectCatalogSearchCall<'a, C>
Create a builder to help you perform the following task:
Search Catalog resources that consumers have access to, within the scope of the consumer cloud resource hierarchy context.
Arguments
resource- Required. The name of the resource context. It can be in following formats: *projects/{project_id}*folders/{folder_id}*organizations/{organization_id}
Sourcepub fn products_search(&self, resource: &str) -> ProjectProductSearchCall<'a, C>
pub fn products_search(&self, resource: &str) -> ProjectProductSearchCall<'a, C>
Create a builder to help you perform the following task:
Search Product resources that consumers have access to, within the scope of the consumer cloud resource hierarchy context.
Arguments
resource- Required. The name of the resource context. See SearchCatalogsRequest.resource for details.
Sourcepub fn versions_search(&self, resource: &str) -> ProjectVersionSearchCall<'a, C>
pub fn versions_search(&self, resource: &str) -> ProjectVersionSearchCall<'a, C>
Create a builder to help you perform the following task:
Search Version resources that consumers have access to, within the scope of the consumer cloud resource hierarchy context.
Arguments
resource- Required. The name of the resource context. See SearchCatalogsRequest.resource for details.